@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-21'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,7 +81,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.06 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-07-02.
+This document describes version 0.07 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-09-21.
 
 =head1 SYNOPSIS
 
@@ -89,6 +89,16 @@ In dist.ini:
 
  [InsertBlock]
 
+In lib/Baz.pm:
+
+ ...
+
+ # BEGIN_BLOCK: some_code
+
+ ...
+
+ # END_BLOCK
+
 In lib/Foo/Base.pm:
 
  ...
@@ -109,6 +119,10 @@ In lib/Foo/Bar.pm:
 
  ...
 
+ # INSERT_BLOCK: lib/Baz.pm some_code
+
+ ...
+
  =head1 ATTRIBUTES
 
  # INSERT_BLOCK: lib/Foo/Bar.pm base_attributes
@@ -146,6 +160,8 @@ to list POD attributes, methods, etc from a base class into a subclass.
 
 =head1 SEE ALSO
 
+L<Dist::Zilla::Plugin::InsertBlock::FromModule>
+
 L<Dist::Zilla::Plugin::InsertCodeResult>
 
 L<Dist::Zilla::Plugin::InsertCodeOutput>
