@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock::FromModule;
 
-our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-09-21'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ Dist::Zilla::Plugin::InsertBlock::FromModule - Insert a block of text from anoth
 
 =head1 VERSION
 
-This document describes version 0.06 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-07-02.
+This document describes version 0.07 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-09-21.
 
 =head1 SYNOPSIS
 
@@ -56,10 +56,40 @@ In dist.ini:
 
  [InsertBlock::FromModule]
 
+In lib/Baz.pm:
+
+ ...
+
+ # BEGIN_BLOCK: some_code
+
+ ...
+
+ # END_BLOCK
+
+In lib/Foo/Base.pm:
+
+ ...
+
+ =head1 ATTRIBUTES
+
+ =for BEGIN_BLOCK: base_attributes
+
+ =head2 attr1
+
+ =head2 attr2
+
+ =for END_BLOCK: base_attributes
+
+ ...
+
 In lib/Foo/Bar.pm:
 
  ...
 
+ # INSERT_BLOCK_FROM_MODULE: Bar some_code
+
+ ...
+
  =head1 ATTRIBUTES
 
  # INSERT_BLOCK_FROM_MODULE: Foo::Base base_attributes
